#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-dijkstra
version:              0.1.1.3
visibility:           public
id:                   monad-dijkstra-0.1.1.3-B13usiK90zR1trO1mL9Dlc
key:                  monad-dijkstra-0.1.1.3-B13usiK90zR1trO1mL9Dlc
license:              BSD-3-Clause
copyright:            Copyright (c) 2016-2020 Enno Cramer
maintainer:           Enno Cramer <ecramer@memfrob.de>
author:               Enno Cramer
homepage:             https://github.com/ennocramer/monad-dijkstra
synopsis:             A monad transformer for weighted graph searches
description:
    A monad transformer for weighted graph searches using Dijkstra'\''s or A* algorithm.

category:             Control, Monads
abi:                  b6e35d4e81c8ccb3b78efaf21fc9a981
exposed:              True
exposed-modules:      Control.Monad.Search
import-dirs:          /usr/lib/ghc-8.10.5/site-local/monad-dijkstra-0.1.1.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/monad-dijkstra-0.1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/monad-dijkstra-0.1.1.3
hs-libraries:         HSmonad-dijkstra-0.1.1.3-B13usiK90zR1trO1mL9Dlc
depends:
    base-4.14.2.0 containers-0.6.4.1 free-5.1.7-G4cc1Y718fXDuPxii9x6Pg
    mtl-2.2.2 psqueues-0.2.7.2-6e78NeiNs41729YcOypUQ3
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-monad-dijkstra/html/monad-dijkstra.haddock

haddock-html:         /usr/share/doc/haskell-monad-dijkstra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

